Struct content_tree::MutCursor [−][src]
#[repr(transparent)]pub struct MutCursor<'a, E: ContentTraits, I: TreeIndex<E>, const IE: usize, const LE: usize> {
pub inner: UnsafeCursor<E, I, IE, LE>,
// some fields omitted
}Expand description
A mutable cursor into a ContentTree. Mutable cursors inherit all the functionality of Cursor, and can also be used to modify the content tree.
A mutable cursor mutably borrows the content tree. Only one mutable cursor can exist at a time.
Fields
inner: UnsafeCursor<E, I, IE, LE>Implementations
pub unsafe fn unchecked_from_raw(
_tree: &mut Pin<Box<ContentTreeRaw<E, I, IE, LE>>>,
cursor: UnsafeCursor<E, I, IE, LE>
) -> Self
pub fn insert_notify<F>(&mut self, new_entry: E, notify: F) where
F: FnMut(E, NonNull<NodeLeaf<E, I, IE, LE>>),
pub fn replace_range_notify<N>(&mut self, new_entry: E, notify: N) where
N: FnMut(E, NonNull<NodeLeaf<E, I, IE, LE>>),
pub fn delete_notify<F>(&mut self, del_items: usize, notify: F) where
F: FnMut(E, NonNull<NodeLeaf<E, I, IE, LE>>),
Methods from Deref<Target = Cursor<'a, E, I, IE, LE>>