Struct content_tree::NodeLeaf[][src]

pub struct NodeLeaf<E: ContentTraits, I: TreeIndex<E>, const INT_ENTRIES: usize, const LEAF_ENTRIES: usize> { /* fields omitted */ }
A leaf node in the B-tree. Except the root, each child stores MAX_CHILDREN/2 - MAX_CHILDREN entries.

The details in a leaf node are private. This is exposed to allow consumers to build custom indexes, allowing for fast cursor creation without needing to iterate through the tree.

See diamond-types for an example of this.

Implementations

Remove a single item from the node