A leaf node in the B-tree. Except the root, each child stores MAX_CHILDREN/2 - MAX_CHILDREN
entries.
The details in a leaf node are private. This is exposed to allow consumers to build custom
indexes, allowing for fast cursor creation without needing to iterate through the tree.
See diamond-types for an example of this.
Remove a single item from the node
Formats the value using the given formatter. Read more
impl<E, I, const INT_ENTRIES: usize, const LEAF_ENTRIES: usize> !Send for NodeLeaf<E, I, INT_ENTRIES, LEAF_ENTRIES>
impl<E, I, const INT_ENTRIES: usize, const LEAF_ENTRIES: usize> !Sync for NodeLeaf<E, I, INT_ENTRIES, LEAF_ENTRIES>
impl<E, I, const INT_ENTRIES: usize, const LEAF_ENTRIES: usize> !Unpin for NodeLeaf<E, I, INT_ENTRIES, LEAF_ENTRIES>
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.