Struct content_tree::UnsafeCursor [−][src]
pub struct UnsafeCursor<E: ContentTraits, I: TreeIndex<E>, const IE: usize, const LE: usize> {
pub offset: usize,
// some fields omitted
}Expand description
A cursor into some location in a range tree.
Note the state of a cursor is weird in two situations:
- When a cursor points to a location in between two entries, the cursor could either point to the end of the first entry or the start of the subsequent entry.
- When a tree is empty, the cursor points past the end of the tree.
Safety: This is unsafe because there’s no associated lifetime on a cursor (its ’static).
The caller must ensure any reads and mutations through an UnsafeCursor are valid WRT the mutability and lifetime of the implicitly referenced content tree. Use Cursor and MutCursor.
Fields
offset: usizeImplementations
impl<E: ContentTraits, I: TreeIndex<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits, I: TreeIndex<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
Internal method for prev_entry and next_entry when we need to move laterally. This moves the cursor to the next / prev node in the tree, with no regard for the current position.
Returns true if the move was successful, or false if we’re at the first / last item in the tree.
Move back to the previous entry. Returns true if it exists, otherwise returns false if we’re at the start of the doc already.
Go to the next entry marker and update the (optional) flush marker. Returns true if successful, or false if we’ve reached the end of the document.
Note this ignores the cursor’s offset.
This is a terrible name. This method modifies a cursor at the end of an entry to be a cursor to the start of the next entry - potentially in the following leaf.
Returns false if the resulting cursor location points past the end of the tree.
This helper method attempts to minimize the size of the leaf around the cursor using append() methods, when possible.
impl<E: ContentTraits + Searchable, I: TreeIndex<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits + Searchable, I: TreeIndex<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits + ContentLength, I: FindContent<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits + ContentLength, I: FindContent<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits, I: FindOffset<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>
impl<E: ContentTraits, I: FindOffset<E>, const IE: usize, const LE: usize> UnsafeCursor<E, I, IE, LE>