Trait content_tree::Toggleable[][src]

pub trait Toggleable {
    fn is_activated(&self) -> bool;
fn mark_activated(&mut self);
fn mark_deactivated(&mut self); fn is_deactivated(&self) -> bool { ... } }
This trait marks items as being able to toggle on and off. The motivation for this is CRDT items which want to stay in a list even after they’ve been deleted.

Required methods

Provided methods

Implementors